@@ -33,6 +33,7 @@ from tinycoder.ui.console_interface import ring_bell, ConsoleInterface
 from tinycoder.ui.command_completer import CommandCompleter, READLINE_AVAILABLE as COMPLETION_READLINE_AVAILABLE
 from tinycoder.ui.log_formatter import ColorLogFormatter, STYLES, COLORS as FmtColors, RESET
 from tinycoder.ui.spinner import Spinner
+from tinycoder.docker_manager import DockerManager
 
 COMMIT_PREFIX = "🤖 tinycoder: "
 HISTORY_FILE = ".tinycoder_history"
@@ -48,6 +49,7 @@ class App:
         self._init_spinner()
         self._setup_git()
         self._init_core_managers(continue_chat)
+        self._setup_docker() # Initialize Docker manager
         self._init_prompt_builder()
         self._setup_rules_manager()
         self._init_input_preprocessor() # Initialize InputPreprocessor
@@ -146,7 +148,7 @@ class App:
                 if initialized:
                     self.git_root = self.git_manager.get_root() # Re-fetch the root after init
                     if self.git_root:
-                        self.logger.info(f"Git repository initialized. Root: {self.git_root}")
+                        self.logger.info(f"Git repository initialized. Root: {FmtColors['CYAN']}{self.git_root}{RESET}")
                     else:
                         # Should not happen if initialize_repo succeeded, but handle defensively
                         self.logger.error("Git initialization reported success, but failed to find root afterwards. Proceeding without Git integration.")
@@ -155,7 +157,7 @@ class App:
             else:
                 self.logger.warning("Proceeding without Git integration.")
         else:
-            self.logger.debug(f"Found existing Git repository. Root: {self.git_root}")
+            self.logger.debug(f"Found existing Git repository. Root: {FmtColors['CYAN']}{self.git_root}{RESET}")
             # If git_root was found initially, we don't need to prompt or initialize
 
         # self.git_root is now set correctly (or None)
@@ -168,6 +170,21 @@ class App:
         self.repo_map = RepoMap(self.git_root) # Pass the final git_root
         self.logger.debug("Core managers (File, History, RepoMap) initialized.")
 
+    def _setup_docker(self) -> None:
+        """Initializes the DockerManager if Docker is available."""
+        # Depends on self.git_root being set, or cwd if not.
+        project_root = Path(self.git_root) if self.git_root else Path.cwd()
+        try:
+            self.docker_manager: Optional[DockerManager] = DockerManager(project_root, self.logger)
+            if not self.docker_manager.is_available:
+                self.docker_manager = None # Ensure it's None if not fully available
+                self.logger.info("Docker integration disabled.")
+            else:
+                self.logger.debug("DockerManager initialized successfully.")
+        except Exception as e:
+            self.logger.warning(f"Could not initialize Docker integration: {e}", exc_info=self.verbose)
+            self.docker_manager = None
+
     def _init_prompt_builder(self) -> None:
         """Initializes the PromptBuilder."""
         # Depends on FileManager and RepoMap
@@ -324,6 +341,7 @@ class App:
         self.command_handler = CommandHandler(
             file_manager=self.file_manager,
             git_manager=self.git_manager,
+            docker_manager=self.docker_manager,
             clear_history_func=self.history_manager.clear,
             write_history_func=self.history_manager.save_message_to_file_only,
             get_mode=lambda: self.mode,
@@ -361,8 +379,130 @@ class App:
         self.input_func = self.console_interface.determine_input_function()
         self.logger.debug("App components (Parser, Applier, ShellExecutor, Input Func from ConsoleInterface) initialized.")
 
+    def _handle_docker_automation(self, modified_files_rel: List[str], non_interactive: bool = False):
+        """
+        After edits are applied, checks for Docker context and automates actions.
+        - Restarts services that don't have live-reload.
+        - Prompts to build if dependency files change.
+        """
+        if not self.docker_manager or not self.docker_manager.is_available or not self.docker_manager.services:
+            self.logger.debug("Docker automation skipped: manager not available or no services found.")
+            return
+
+        modified_files_abs = [self.file_manager.get_abs_path(f) for f in modified_files_rel if self.file_manager.get_abs_path(f)]
+        if not modified_files_abs:
+            return # No valid files to check
+
+        # find_affected_services now returns Dict[str, Set[str]]
+        affected_services_map = self.docker_manager.find_affected_services(modified_files_abs)
+        if not affected_services_map:
+            self.logger.debug("No Docker services affected by file changes.")
+            return
+
+        dependency_files = ["requirements.txt", "pyproject.toml", "package.json", "Pipfile", "Dockerfile"] # Added Dockerfile
+        modified_dep_files = any(Path(f).name.lower() in dependency_files for f in modified_files_rel) # .lower() for Dockerfile
+
+        services_to_build_and_restart = set()
+        services_to_volume_restart_only = set()
+
+        for service_name, reasons in affected_services_map.items():
+            needs_build = False
+            # If any global dep file changed for *any* service, all *affected* services are marked for build.
+            # Or if Dockerfile specific to a service's build context (or the context itself) changes.
+            if modified_dep_files: 
+                # Check if this specific service's Dockerfile or build context is among the changed dependency files
+                service_build_config = self.docker_manager.services.get(service_name, {}).get('build', {})
+                service_build_context_str = None
+                if isinstance(service_build_config, str):
+                    service_build_context_str = service_build_config
+                elif isinstance(service_build_config, dict):
+                    service_build_context_str = service_build_config.get('context')
+                
+                service_dockerfile_str = "Dockerfile" # default
+                if isinstance(service_build_config, dict) and isinstance(service_build_config.get('dockerfile'), str):
+                     service_dockerfile_str = service_build_config.get('dockerfile')
+
+
+                if service_build_context_str and self.docker_manager.root_dir:
+                    service_build_context_path = (self.docker_manager.root_dir / service_build_context_str).resolve()
+                    
+                    # Check if any modified dep file is THE Dockerfile for this service, or within its context
+                    for mod_file_rel in modified_files_rel:
+                        mod_file_abs = self.file_manager.get_abs_path(mod_file_rel)
+                        if not mod_file_abs: continue
+
+                        # Is the modified file the Dockerfile for this service?
+                        # Resolve path to Dockerfile relative to context
+                        dockerfile_abs_path = (service_build_context_path / service_dockerfile_str).resolve()
+                        if mod_file_abs == dockerfile_abs_path:
+                            needs_build = True
+                            self.logger.debug(f"Service '{service_name}' Dockerfile '{service_dockerfile_str}' changed.")
+                            break
+                        # Is a generic dep file (like requirements.txt) inside this service's build context?
+                        if mod_file_abs.name.lower() in dependency_files and mod_file_abs.is_relative_to(service_build_context_path):
+                            needs_build = True
+                            self.logger.debug(f"Dependency file '{mod_file_abs.name}' changed within build context of '{service_name}'.")
+                            break
+                    if needs_build:
+                         self.logger.debug(f"Service '{service_name}' marked for build due to specific dependency change.")
+
+
+            if "build_context" in reasons and not needs_build: # if not already caught by dep check
+                needs_build = True
+                self.logger.debug(f"Service '{service_name}' marked for build due to direct build_context change.")
+
+            if needs_build:
+                services_to_build_and_restart.add(service_name)
+            elif "volume" in reasons: # Only consider for volume restart if not already needing a build
+                if self.docker_manager.is_service_running(service_name):
+                    if not self.docker_manager.has_live_reload(service_name):
+                        services_to_volume_restart_only.add(service_name)
+                    else:
+                        self.logger.info(f"Service '{service_name}' affected by volume change and has live-reload, no automatic restart needed.")
+                else:
+                    self.logger.debug(f"Service '{service_name}' affected by volume change but not running, skipping restart.")
+        
+        if services_to_build_and_restart:
+            sorted_build_services = sorted(list(services_to_build_and_restart))
+            self.logger.warning(
+                f"Services requiring build & restart: {', '.join(sorted_build_services)}"
+            )
+            if non_interactive:
+                self.logger.info("Non-interactive mode: Skipping build & restart prompt. Please manage manually.")
+            else:
+                try:
+                    confirm = input(f"Rebuild and restart affected services ({', '.join(sorted_build_services)}) now? (y/N): ").strip().lower()
+                    if confirm == 'y':
+                        for service in sorted_build_services:
+                            if self.docker_manager.build_service(service): 
+                                self.docker_manager.restart_service(service) 
+                            # else: build failed, build_service logged it.
+                except (EOFError, KeyboardInterrupt):
+                    self.logger.info("\nBuild & restart cancelled by user.")
+            return # Exit after build consideration, regardless of user choice
+
+        # Handle services that only needed a volume-based restart (and weren't built)
+        if services_to_volume_restart_only:
+            sorted_volume_services = sorted(list(services_to_volume_restart_only))
+            self.logger.info(
+                f"Services requiring restart due to volume changes (no live-reload): {', '.join(sorted_volume_services)}"
+            )
+            if non_interactive:
+                self.logger.info("Non-interactive mode: Skipping volume-based restart. Please manage manually.")
+            else:
+                try:
+                    # Could add a prompt here too if desired, but for now, auto-restarting these.
+                    # confirm_restart = input(f"Restart services ({', '.join(sorted_volume_services)}) now? (y/N): ").strip().lower()
+                    # if confirm_restart == 'y':
+                    for service in sorted_volume_services:
+                        self.logger.info(f"Service '{service}' is running without apparent live-reload and affected by volume change.")
+                        self.docker_manager.restart_service(service)
+                except (EOFError, KeyboardInterrupt):
+                    self.logger.info("\nVolume restart cancelled by user.")
+
+
     def _log_final_status(self) -> None:
-        """Logs the final Git integration status after all setup."""
+        """Logs the final Git and Docker integration status after all setup."""
         if not self.git_manager.is_git_available():
             # Warning already logged during init
             self.logger.debug("Final check: Git is unavailable. Git integration disabled.")
@@ -371,20 +511,33 @@ class App:
             self.logger.warning("Final check: Not inside a git repository. Git integration disabled.")
         else:
             # Git is available and we have a root
-            self.logger.debug(f"Final check: Git repository root confirmed: {self.git_root}")
+            self.logger.debug(f"Final check: Git repository root confirmed: {FmtColors['CYAN']}{self.git_root}{RESET}")
             # Ensure RepoMap knows the root (should be set by _init_core_managers)
             if self.repo_map.root is None: # Defensive check
                  self.logger.warning("RepoMap root was unexpectedly None, attempting to set.")
                  self.repo_map.root = Path(self.git_root)
             elif str(self.repo_map.root.resolve()) != str(Path(self.git_root).resolve()):
-                self.logger.warning(f"Mismatch between GitManager root ({self.git_root}) and RepoMap root ({self.repo_map.root}). Using GitManager root.")
+                self.logger.warning(f"Mismatch between GitManager root ({FmtColors['CYAN']}{self.git_root}{RESET}) and RepoMap root ({FmtColors['CYAN']}{self.repo_map.root}{RESET}). Using GitManager root.")
                 self.repo_map.root = Path(self.git_root)
+        
+        # Docker part
+        if self.docker_manager and self.docker_manager.is_available:
+            self.logger.debug("Final check: Docker integration is active.")
+            if self.docker_manager.compose_file:
+                self.logger.debug(f"Using compose file: {FmtColors['CYAN']}{self.docker_manager.compose_file}{RESET}")
+            # Check for missing volume mounts for any initial files
+            if self.file_manager.get_files():
+                files_in_context_abs = [self.file_manager.get_abs_path(f) for f in self.file_manager.get_files() if self.file_manager.get_abs_path(f)]
+                self.docker_manager.check_for_missing_volume_mounts(files_in_context_abs)
+        else:
+            self.logger.debug("Final check: Docker integration is disabled.")
 
 
     def _add_initial_files(self, files: List[str]) -> None:
         """Adds initial files specified via command line arguments."""
         if files:
-            self.logger.info(f"Adding initial files to context: {', '.join(files)}")
+            colored_files = [f"{FmtColors['CYAN']}{f}{RESET}" for f in files]
+            self.logger.info(f"Adding initial files to context: {', '.join(colored_files)}")
             added_count = 0
             for fname in files:
                 if self.file_manager.add_file(fname):
@@ -628,7 +781,7 @@ class App:
                 # Warn if a specifically requested path doesn't exist
                 if paths_to_commit is not None:
                     self.logger.warning(
-                        f"Requested commit path {fname} does not exist on disk, skipping.",
+                        f"Requested commit path {FmtColors['CYAN']}{fname}{RESET} does not exist on disk, skipping.",
                     )
                 # Don't warn if iterating all context files and one is missing (it might have been deleted)
 
@@ -764,10 +917,11 @@ class App:
                     successfully_added_fnames.append(fname)
             
             if added_count > 0:
-                tool_message = f"Added {added_count} file(s) to context from LLM request: {', '.join(successfully_added_fnames)}"
+                colored_successfully_added_fnames = [f"{FmtColors['CYAN']}{f}{RESET}" for f in successfully_added_fnames]
+                tool_message = f"Added {added_count} file(s) to context from LLM request: {', '.join(colored_successfully_added_fnames)}"
                 self.history_manager.save_message_to_file_only("tool", tool_message)
                 reflection_content = (
-                    f"The following files have been added to the context as per your request: {', '.join(successfully_added_fnames)}. "
+                    f"The following files have been added to the context as per your request: {', '.join(colored_successfully_added_fnames)}. "
                     "Please proceed with the original task based on the updated context."
                 )
                 self.reflected_message = reflection_content
@@ -781,7 +935,7 @@ class App:
 
         return False
 
-    def process_user_input(self):
+    def process_user_input(self, non_interactive: bool = False):
         """Processes the latest user input (already in history), sends to LLM, handles response."""
         response = self._send_to_llm()
 
@@ -813,6 +967,8 @@ class App:
                     if all_succeeded:
                         if modified_files:
                             self.logger.info("All edits applied successfully.")
+                            # Automate Docker actions before committing
+                            self._handle_docker_automation(list(modified_files), non_interactive=non_interactive)
                             self._git_add_commit(list(modified_files))
                         else:
                             self.logger.info("Edits processed, but no files were changed.")
@@ -836,7 +992,7 @@ class App:
                 if self.lint_errors_found and not self.reflected_message: 
                     error_messages = ["Found syntax errors after applying edits:"]
                     for fname, error in self.lint_errors_found.items():
-                        error_messages.append(f"\n--- Errors in {fname} ---\n{error}")
+                        error_messages.append(f"\n--- Errors in {FmtColors['CYAN']}{fname}{RESET} ---\n{error}")
                     combined_errors = "\n".join(error_messages)
                     self.logger.error(combined_errors)
 
@@ -893,12 +1049,17 @@ class App:
                 existing_files.append(fname)
             else:
                 self.logger.warning(
-                    f"Ignoring non-existent file suggested by LLM: {fname}"
+                    f"Ignoring non-existent file suggested by LLM: {FmtColors['CYAN']}{fname}{RESET}"
                 )
-
-        self.logger.info(
-            f"LLM suggested files (after filtering): {', '.join(existing_files)}",
-        )
+        
+        if existing_files:
+            colored_existing_files = [f"{FmtColors['CYAN']}{f}{RESET}" for f in existing_files]
+            self.logger.info(
+                f"LLM suggested files (after filtering): {', '.join(colored_existing_files)}",
+            )
+        else:
+            self.logger.info("LLM suggested no existing files after filtering.")
+            
         return existing_files
 
     def init_before_message(self):
@@ -1063,7 +1224,7 @@ class App:
 
         # Initial processing of the user message
         self.history_manager.add_message("user", message)  # Use history manager
-        self.process_user_input()  # This now handles LLM call, edits, linting
+        self.process_user_input(non_interactive=non_interactive)  # This now handles LLM call, edits, linting
 
         # Check if reflection is needed *and* allowed (interactive mode)
         while not non_interactive and self.reflected_message:
@@ -1087,7 +1248,7 @@ class App:
 
             # Add the reflected message to history *before* processing
             self.history_manager.add_message("user", message)
-            self.process_user_input()  # Process the reflected input
+            self.process_user_input(non_interactive=non_interactive)  # Process the reflected input
 
         return True  # Indicate normal processing occurred (or finished reflection loop)
 
@@ -1138,9 +1299,27 @@ class App:
         active_rules_line = f"  Rules: {active_rules_status_output_str}"
         help_line = f"  Type {FmtColors['CYAN']}{STYLES['BOLD']}/help{RESET} for commands, or {FmtColors['CYAN']}{STYLES['BOLD']}!<cmd>{RESET} to run shell commands. \n"
 
+        # Determine Docker status string
+        docker_status_output_str: str
+        if self.docker_manager and self.docker_manager.is_available:
+            if self.docker_manager.compose_file:
+                # Attempt to get a relative path for the compose file for cleaner display
+                compose_file_display_path = str(self.docker_manager.compose_file)
+                if self.docker_manager.root_dir and self.docker_manager.compose_file.is_relative_to(self.docker_manager.root_dir):
+                    compose_file_display_path = str(self.docker_manager.compose_file.relative_to(self.docker_manager.root_dir))
+                
+                docker_status_output_str = f"{FmtColors['GREEN']}{STYLES['BOLD']}Enabled{RESET} (compose: {FmtColors['CYAN']}{compose_file_display_path}{RESET})"
+            else:
+                docker_status_output_str = f"{FmtColors['YELLOW']}{STYLES['BOLD']}Enabled (no compose file detected){RESET}"
+        else:
+            docker_status_output_str = f"{STYLES['BOLD']}Disabled{RESET}"
+        
+        docker_line = f"  Docker: {docker_status_output_str}"
+
         # Log each part on a new line for clarity
         self.logger.info(model_line)
         self.logger.info(repo_map_line)
+        self.logger.info(docker_line) # Added Docker status line
         self.logger.info(active_rules_line)
         self.logger.info(help_line)
         
